/*
 *  Copyright 2010 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */

Ext.namespace('org.ametys.cms.tool.iframe');

org.ametys.cms.tool.iframe.OpenUrlButton = function(id, configuration, pluginName)
{
	org.ametys.cms.tool.iframe.OpenUrlButton.superclass.constructor.call(this, id, configuration, pluginName);
}

Ext.extend(org.ametys.cms.tool.iframe.OpenUrlButton, org.ametys.ribbon.control.button.UniqueInstanceToolButton, {});

org.ametys.cms.tool.iframe.OpenUrlButton.prototype.createControl = function(size, colspan)
{
	var element = org.ametys.cms.tool.iframe.OpenUrlButton.superclass.createControl.call(this, size, colspan);
	if (this.getConfiguration()['external'] == 'true')
	{
		element.enableToggle = false;
		element.toggleHandler = null;
		element.handler = this.onPress;
	}
	return element;
}

org.ametys.cms.tool.iframe.OpenUrlButton.prototype.onPress = function (button, event)
{
	var control = org.ametys.ribbon.RibbonManager.getInstance().getControls()[this.controlId];
	window.open(control.getConfiguration()['url']);
}

org.ametys.cms.tool.iframe.OpenUrlButton.prototype.onToggle = function (button, state)
{
	var control = org.ametys.ribbon.RibbonManager.getInstance().getControls()[this.controlId];
	var toolParams = control.getOpenToolParameters();
	
	/*if (toolParams['external'] == 'true')
	{
		window.open(toolParams['url']);
		this.toggle(false, true);
	}
	else */if (state)
	{
		org.ametys.uitool.ToolsManager.getInstance().openTool(control.getConfiguration()['role'], toolParams);
	}
	else
	{
		var tool = org.ametys.uitool.ToolsManager.getInstance().getTool(org.ametys.cms.tool.iframe.IframeToolFactory._toolIdPrefix + toolParams['url']);
		
		if (tool.toolsPanel.getActiveTab() != tool.parent)
		{
			org.ametys.uitool.ToolsManager.getInstance().activateTool (tool, tool._factory._config['default-location']);
			this.toggle(true);
		}
		else
		{
			tool.close();
		}
	}
}

org.ametys.cms.tool.iframe.OpenUrlButton.prototype.getOpenToolParameters = function()
{
	var params = org.ametys.cms.tool.iframe.OpenUrlButton.superclass.getOpenToolParameters.call(this);
	params['controlId'] = this._id;
	params['url'] = this.getConfiguration()['url'];
	params['external'] = this.getConfiguration()['external'];
	params['title'] = this.getConfiguration()['label'];
	params['description'] = this.getConfiguration()['default-description'];
	params['icon-small'] = this.getConfiguration()['icon-small'];
	params['icon-medium'] = this.getConfiguration()['icon-medium'];
	params['icon-large'] = this.getConfiguration()['icon-large'];
	
	return params;
}

org.ametys.cms.tool.iframe.OpenUrlButton.prototype.isInTarget = function(targets)
{
	var control = org.ametys.ribbon.RibbonManager.getInstance().getControls()[this.getId()];
	for (var i = 0; i < targets.length; i++)
	{
		var target = targets[i];
		
		if (target.getType() == "tool" && target.getParameters()['id'] == org.ametys.cms.tool.iframe.IframeToolFactory._toolIdPrefix + control.getConfiguration()['url'])
		{
			return true;
		}
		
		if (this.isInTarget(target.getSubTargets()))
		{
			return true;
		}
	}
	
	return false;
}